@@ -7,7 +7,7 @@ from config import (
 import tweepy
 
 
-class TweepyTestCase(unittest.TestCase):
+class TweepyClientTests(unittest.TestCase):
 
     def setUp(self):
         self.client = tweepy.Client(
@@ -82,6 +82,10 @@ class TweepyTestCase(unittest.TestCase):
         user_id = 783214  # User ID for @Twitter
         self.client.get_users_mentions(user_id)
 
+    @tape.use_cassette("test_client_get_home_timeline.yaml")
+    def test_get_home_timeline(self):
+        self.client.get_home_timeline()
+
     @tape.use_cassette("test_client_get_users_tweets.yaml")
     def test_get_users_tweets(self):
         user_id = 783214  # User ID for @Twitter
@@ -107,7 +111,7 @@ class TweepyTestCase(unittest.TestCase):
         self.client.get_tweets(tweet_ids)
 
     @tape.use_cassette("test_client_block_and_get_blocked_and unblock.yaml")
-    def test_block_and_unblock(self):
+    def test_block_and_get_blocked_and_unblock(self):
         user_id = 17874544  # User ID for @TwitterSupport
         self.client.block(user_id)
         self.client.get_blocked()
